.. todo shield.io badges

=====================
Django Content Blocks
=====================

Django Content Blocks is a reusable Django app that allows users to create and manage custom content blocks for their website. Via the django admin site it provides an easy-to-use interface for creating content blocks that can be inserted into any page, as well as a powerful template system for customizing the appearance of those blocks.

Content blocks can contain any type of content, including text, images, videos, and more, and can be arranged in any order on a page. Additionally, Django Content Blocks includes support for drafts and previews, allowing users to see how their changes will look before publishing them.

.. todo screenshot goes here

Installation instructions and detailed documentation can be found on ReadTheDocs.

Supported Django & Python Versions
----------------------------------

Python >= 3.7
Django >= 3.2

Dependencies (and Thank You)
----------------------------

* https://github.com/jrief/django-admin-sortable2
* https://github.com/tj-django/django-clone - Additional thanks for tox.ini setup

Thank You
---------

* https://shystudios.co.uk - For the monies I need to eat
* https://opalstack.com/?lmref=A2GlhA - For great value hosting and superb support over the years (affiliate link)
* https://chat.openai.com/ - For documentation rewrites
* https://github.com/django-hijack/django-hijack - For conf.py LazySettings idea
* https://github.com/cookiecutter/cookiecutter-django - For many things include docker

Contributing
------------

Contributions, advice and guidance are welcome. Please make contact **before** writing any code!
